bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 19. Aventiure
___________________________________________________ #### <Wie der Niblvnge hort ze Wormz chom>
| ### o div edel Kriemhilt also verwitwet wart ### bi ir in mime lande der raue Ekewart ### beleip mit sinen mannen der diende ir ze allen tagen ### vnd half ovch siner vrovwen sinen herren dike clagen
###### 1042 | ### Ze Wormz bi dem mvnster ein gecimber man ir sloz ### wit vnd vil mikel rich vn– groz ### da si mit ir gesinde sid an frovde saz ### si was ze kirken gerne vnd tet vil willichlichen daz
###### 1043 | ### Da man begruop ir vriedel wie selten si daz lie ### mit trurigem mvote si alle zit dar gie ### vn– bat got den guoten siner sele phlegen ### vil dike wart beweinet mit grozen triwen der degen
###### 1044 | ### vote vnd ir gesinde trosten si alle stvnt ### do was ir daz herze so grozlichen wunt ### daz kvnde niht vervahen swaz man ir trostes bot ### si het nach liebem vrivnde die aller grozisten not
###### 1045 | ### die nach liebem manne ie nie wip gewan ### man mohe ir michel tvgende kiesen wol dar an ### si klagete vnz an ir ende die wile werte ir lip [43a] ### sid rach sich wol ellen des kuenen Sifrides wip
###### 1046 | ### Sus saz si nach ir leide daz ist alwar ### nach ir mannes tode wol vierdhalp iar ### daz si ze Gvnther nie chein wort gesprach ### vnd ir vint Hagnen in der cit nie gesach
###### 1047 | ### Do sprach von Troni Hagne muget ir daz tragen an ### da ir iwer swester ce frivnt mohtet han ### so koeme zuo disem lande der Niblvnge <golt > ### des moehtet ir vil gewinnen wurde uns div kuniginne holt
###### 1048 | ### Er sprach wir svlnz versuochen mine bruoder sint ir bi ### die svlen wir biten werben daz si vnser vriunt si ### vnd ovb wir in gewinnen daz si daz gerne sehe ### ich trovwes niht sprach Hagne daz ez immer geschehe
###### 1049 | ### Do hiez er Ortwinen hin ze hove gan ### vn– den marchgrauen Geren do daz was geschehen ### man brahte ovch Gernote vnd Giselher daz kint ### si versuohtenz vriuntlichen an vro Kriemhilde sint
###### 1050 | ### Do sprach von Bvrgonden der kuene Gernot ### vrovwe ir klaget ze lange den Sifrides tot ### iu wil der kvnich rihten daz er sin niht hat erslagen ### man hoert iv zallen ziten so rehte grozlichen clagen
###### 1051 | ### Si sprach des zihet in nieman in sluoch Hagnen hant ### wa man ir verhovwen solde do er daz an mir ervant ### wie moht ich des trûwen daz er im truoge haz ### ich hete wol behvotet sprach div kvniginne daz
###### 1052 | ### daz ich vermeldet hete sin schoenen lip ### so lieze ich nv min weinen ich vil armez wip ### holt wird ich nimmer in die ez da hant getan ### do begvnde flegen Giselher der vil wetliche man
###### 1053 | ### Ich wil den kvnich gruozen do si im des veriach ### mit sinen besten vrivnden man in vor ir sach ### do getorste Hagne fur si niht gegan ### wol weste er sine schvlde er hete ir leide getan
###### 1054 | ### Do si verkiesen <wolde> vf Gvnther den haz ### ob er si chvssen solde ez zeme im dester baz ### wer ir von sime rate leide niht getan ### so moeht er vreveliche dike sin zuo ir gegan
###### 1055 | ### Ez en wart nie <suone> mit so vil træhen me ### gefueget vnder frivnden ir tet ir schade vil we ### si verkos vf si alle wan vf den einen man ### in hete erslagen niemen het ez Hagne niht getan
###### 1056 | ### Darnach vil vnlange do truogen si daz an ### daz div frovwe Kriemhilt den grozen hort gewan ### von Niblvnges lande vn– fuorte in an den Rin ### ez was ir morgengabe er sold ir billichen sin
###### 1057 | ### Darnach fuor do Giselher vn– ovch Gernot ### ahcek hvndert mannen Kriemhilt do gebot ### daz si in holen solden daz er verborgen lac ### da sin der degen Albrich mit sinen besten vrivnde pflac
###### 1058 | ### Do man die von Rine nach dem <schatze> komen sach [43b] ### Albrich der vil kvene zuo sinen vrivnden sprach ### wir turren ir des hordes vor gehaben niht ### sit sin ce morgengabe div edel kvniginne giht
###### 1059 | ### Doch enwurdez nimmer sprach Albrich getan ### niwan daz wir vbele da verlorn han ### mit samet Sifride die gvoten tarnhuot ### wan die truoch alle zite der <schonen> Kriemhilde trût
###### 1060 | ### Nv ist ez Sifride leider ubel komen ### daz vns die tarnkappen der helt hete benomen ### vnd daz im mvose dienen allez dizze lant ### do gie der kamerere da er die sluzzele schiere vant
###### 1061 | ### Ez stuonden vor dem berge Kriemhilde man ### vnd ovch ein teil ir mage den schaz si truogen dan ### zuo dem se an div guoten <schiffelin> ### den fuorte man vf vnden vnce ze berge an den Rin
###### 1062 | ### Ir mvget von dem horte wunder horen sagen ### swaz zuelf kanzwegene meist mohten tragen ### in vier tagen vn– naht von dem berge dan ### ovch muos ir islicher des tages dristvnde gan
###### 1063 | ### Ez was ovch niht anders wan gesteine vn– golt ### vn– ob man al die welt hete versolt ### sin were miner niht einer marke wert ### ia het ez an schvlde Hagne gar niht gegert
###### 1064 | ### Der wunsch lac darunder von golde ein ruotelin ### der daz het erkvnuet der mohte meister sin ### wol in al der werlde vber islichen man ### der Albrikes mage kom vil mit Gernote dan
###### 1065 | ### Do si den hort behielten in Gvnthers lant ### vn– sich div kvniginne des alles vnderwant ### kamere vn– turne sin wurder vol getragen ### man gehorte nie daz wunder von guote mer gesagen
###### 1066 | ### Vnd wær sin tvsent stvnt noch alse vil gewesen ### vn– solde Sifrit gesvnt sin genesen ### bi im wer Kriemhilt hende bloz bestan ### getriwer wibes kvnne ein helt nie mere gewan
###### 1067 | ### Do si den hort nv hete do brahtes in daz lant ### vil vnkvnder reken ia gap der vrovwen hant ### daz man so grozer milte mere nie gesach ### si pflach vil grozer tvgende des man der kvnniginne iach
###### 1068 | ### Den armen vn– der riken begvnde si nv geben ### daz do reite Hagene obe si solde leben ### noch deheine wile daz si so manigen man ### in ir dienst gewunne daz ez in leide muoste ergan
###### 1069 | ### Do sprach kvnich Gvnther ir ist lip vn– guot ### zwi sol ich daz wenden daz si da mite tuot ### ia erwarb ich daz vil kome daz si mir wart holt ### nv enruochen war si teile ir steine vn– ir rotez golt
###### 1070 | ### Hagene sprach zvo dem kvnige ez sold ein frumer man ### deheinem wibe <niht> des hordes lan ### si bringetez mit gabe noch vnze vf den tac [44a] ### daz die wol geriwen die kuenen von Burgonden mac
###### 1071 | ### Do sprach kvnich Gvnther ich swvr ir einen eit ### daz ich ir getete nimer mere leit ### vn– wils furbaz huoten si ist div swester min ### do sprach aber Hagene lat mich der schuldigen sin
###### 1072 | ### Ir svmelicher eide waren vnbehuot ### do nam si der witwen daz keftige guot ### Hagne sich der scluzle aller vnderwant ### daz zvrnde ir bruoder Gernot do er daz rehte bevant
###### 1073 | ### Do sprach der herre Giselher Hagene hat getan ### vil leides miner swester ich soldez vnderstan ### wer er niht min mach ez giench im an den lip ### iteniwez weinen tet do Sifrides wip
###### 1074 | ### Do sprach her Gernot ê wir immer sin ### gemvot mit dem golde wir soldenz in den Rin ### allez heizen senken daz ez wurde nieman ### si gie vil klegeliche fur Giselher ir bruoder stan
###### 1075 | ### Si sprach lieber bruoder dv sold gedenken min ### libes vnde guotes sold dv min voget sin ### do sprach er zuo der vrowen daz sol sin getan ### als wir komen widere wir haben ritens wan
###### 1076 | ### Der kvnich vnd sine magen die rvmten daz lant ### die aller besten darunder die man inder vant ### niwan Hagne eine beleip durch haz ### den er truoch Kriemhilde vnd tet vil schedilichen daz
###### 1077 | ### E der kvnich rike wider wære komen ### die wile hete Hagene den schaz vil gar genomen ### er sancte in da ze loche allen in den Rin ### er wande er soldin niezen des kvnde do niht gesin
###### 1078 | ### Die fvrsten komen wider mit in vil manich man ### Kriemhilt ir grozen schaden klagen do began ### mit vrowen vnd mit meiden in was harte leit ### gerne wer ir Gyselher aller triwen bereit
###### 1079 | ### Do spraken si gemeine er hat vbel getan ### Hagene entweich der fursten zorne also lange dan ### vntz er gewan ir hvlde si liezen in genesen ### do kvnde ime Kriemhilt nimmer viender gewesen
###### 1080 | ### E daz von Trony Hagne da <schatz> also verbarc ### do hetenz siz gevestent mit eiden also starch ### daz er verholn wære vntz ir einer mohte leben ### so enkvnden sis in selben noch ander niemen gegeben
###### 1081 | ### Mit iteniwen leiden beswert was ir mvot ### vmb ir mannes ende vn– do si ir daz guot ### also gar benamen do gestuont ir klage ### des libes nimmer mere vnz an ir iungistem tage
###### 1082 | ### Nach Sifrides tode daz ist al war ### si wonde in manigem sere drivzehen iar ### daz si des reken todes vergezzen kvnde niht ### si was im getriwe des im div meiste menige giht

<<< Übersicht <<< vorige Seite nächste Seite >>>